/*****************************************************************************************
    @author: Arpit Narechania
    @email: arpitnarechania@gmail.com
    @project: d3-molecule

    Copyright 2017 Arpit Narechania

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:
    The above copyright notice and this permission notice shall be included in all
    copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
    EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
    IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
    DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
    OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
    OR OTHER DEALINGS IN THE SOFTWARE.
******************************************************************************************/

var periodicTableData = [
  {
    "Atomic Number": 1,
    "Element": "Hydrogen",
    "Symbol": "H",
    "Atomic Radius": 0.79,
    "Atomic Weight": 1.00794,
    "Period": 1,
    "Group": 1,
    "Phase": "gas",
    "Most Stable Crystal": "",
    "Type": "Nonmetal",
    "Ionic Radius": 0.012,
    "Electronegativity": 2.2,
    "First Ionization Potential": 13.5984,
    "Density": 0.00008988,
    "Melting Point (K)": 14.175,
    "Boiling Point (K)": 20.28,
    "Isotopes": 3,
    "Discoverer": "Cavendish",
    "Year of Discovery": 1766,
    "Specific Heat Capacity": 14.304,
    "Electron Configuration": "1s1",
    "Display Row": 1,
    "Display Column": 1
  },
  {
    "Atomic Number": 2,
    "Element": "Helium",
    "Symbol": "He",
    "Atomic Radius": 0.49,
    "Atomic Weight": 4.002602,
    "Period": 1,
    "Group": 18,
    "Phase": "gas",
    "Most Stable Crystal": "",
    "Type": "Noble Gas",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": 24.5874,
    "Density": 0.0001785,
    "Melting Point (K)": "",
    "Boiling Point (K)": 4.22,
    "Isotopes": 5,
    "Discoverer": "Janssen",
    "Year of Discovery": 1868,
    "Specific Heat Capacity": 5.193,
    "Electron Configuration": "1s2",
    "Display Row": 1,
    "Display Column": 18
  },
  {
    "Atomic Number": 3,
    "Element": "Lithium",
    "Symbol": "Li",
    "Atomic Radius": 2.1,
    "Atomic Weight": 6.941,
    "Period": 2,
    "Group": 1,
    "Phase": "solid",
    "Most Stable Crystal": "bcc",
    "Type": "Alkali Metal",
    "Ionic Radius": 0.76,
    "Electronegativity": 0.98,
    "First Ionization Potential": 5.3917,
    "Density": 0.534,
    "Melting Point (K)": 453.85,
    "Boiling Point (K)": 1615,
    "Isotopes": 5,
    "Discoverer": "Arfvedson",
    "Year of Discovery": 1817,
    "Specific Heat Capacity": 3.582,
    "Electron Configuration": "[He] 2s1",
    "Display Row": 2,
    "Display Column": 1
  },
  {
    "Atomic Number": 4,
    "Element": "Beryllium",
    "Symbol": "Be",
    "Atomic Radius": 1.4,
    "Atomic Weight": 9.012182,
    "Period": 2,
    "Group": 2,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Alkaline Earth Metal",
    "Ionic Radius": 0.35,
    "Electronegativity": 1.57,
    "First Ionization Potential": 9.3227,
    "Density": 1.85,
    "Melting Point (K)": 1560.15,
    "Boiling Point (K)": 2742,
    "Isotopes": 6,
    "Discoverer": "Vaulquelin",
    "Year of Discovery": 1798,
    "Specific Heat Capacity": 1.825,
    "Electron Configuration": "[He] 2s2",
    "Display Row": 2,
    "Display Column": 2
  },
  {
    "Atomic Number": 5,
    "Element": "Boron",
    "Symbol": "B",
    "Atomic Radius": 1.2,
    "Atomic Weight": 10.811,
    "Period": 2,
    "Group": 13,
    "Phase": "solid",
    "Most Stable Crystal": "rho",
    "Type": "Metalloid",
    "Ionic Radius": 0.23,
    "Electronegativity": 2.04,
    "First Ionization Potential": 8.298,
    "Density": 2.34,
    "Melting Point (K)": 2573.15,
    "Boiling Point (K)": 4200,
    "Isotopes": 6,
    "Discoverer": "Gay-Lussac",
    "Year of Discovery": 1808,
    "Specific Heat Capacity": 1.026,
    "Electron Configuration": "[He] 2s2 2p1",
    "Display Row": 2,
    "Display Column": 13
  },
  {
    "Atomic Number": 6,
    "Element": "Carbon",
    "Symbol": "C",
    "Atomic Radius": 0.91,
    "Atomic Weight": 12.0107,
    "Period": 2,
    "Group": 14,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Nonmetal",
    "Ionic Radius": "",
    "Electronegativity": 2.55,
    "First Ionization Potential": 11.2603,
    "Density": 2.267,
    "Melting Point (K)": 3948.15,
    "Boiling Point (K)": 4300,
    "Isotopes": 7,
    "Discoverer": "Prehistoric",
    "Year of Discovery": "",
    "Specific Heat Capacity": 0.709,
    "Electron Configuration": "[He] 2s2 2p2",
    "Display Row": 2,
    "Display Column": 14
  },
  {
    "Atomic Number": 7,
    "Element": "Nitrogen",
    "Symbol": "N",
    "Atomic Radius": 0.75,
    "Atomic Weight": 14.0067,
    "Period": 2,
    "Group": 15,
    "Phase": "gas",
    "Most Stable Crystal": "",
    "Type": "Nonmetal",
    "Ionic Radius": 0.13,
    "Electronegativity": 3.04,
    "First Ionization Potential": 14.5341,
    "Density": 0.0012506,
    "Melting Point (K)": 63.29,
    "Boiling Point (K)": 77.36,
    "Isotopes": 8,
    "Discoverer": "Rutherford",
    "Year of Discovery": 1772,
    "Specific Heat Capacity": 1.04,
    "Electron Configuration": "[He] 2s2 2p3",
    "Display Row": 2,
    "Display Column": 15
  },
  {
    "Atomic Number": 8,
    "Element": "Oxygen",
    "Symbol": "O",
    "Atomic Radius": 0.65,
    "Atomic Weight": 15.9994,
    "Period": 2,
    "Group": 16,
    "Phase": "gas",
    "Most Stable Crystal": "",
    "Type": "Nonmetal",
    "Ionic Radius": 1.4,
    "Electronegativity": 3.44,
    "First Ionization Potential": 13.6181,
    "Density": 0.001429,
    "Melting Point (K)": 50.5,
    "Boiling Point (K)": 90.2,
    "Isotopes": 8,
    "Discoverer": "Priestley/Scheele",
    "Year of Discovery": 1774,
    "Specific Heat Capacity": 0.918,
    "Electron Configuration": "[He] 2s2 2p4",
    "Display Row": 2,
    "Display Column": 16
  },
  {
    "Atomic Number": 9,
    "Element": "Fluorine",
    "Symbol": "F",
    "Atomic Radius": 0.57,
    "Atomic Weight": 18.9984032,
    "Period": 2,
    "Group": 17,
    "Phase": "gas",
    "Most Stable Crystal": "",
    "Type": "Halogen",
    "Ionic Radius": 1.3,
    "Electronegativity": 3.98,
    "First Ionization Potential": 17.4228,
    "Density": 0.001696,
    "Melting Point (K)": 53.63,
    "Boiling Point (K)": 85.03,
    "Isotopes": 6,
    "Discoverer": "Moissan",
    "Year of Discovery": 1886,
    "Specific Heat Capacity": 0.824,
    "Electron Configuration": "[He] 2s2 2p5",
    "Display Row": 2,
    "Display Column": 17
  },
  {
    "Atomic Number": 10,
    "Element": "Neon",
    "Symbol": "Ne",
    "Atomic Radius": 0.51,
    "Atomic Weight": 20.1797,
    "Period": 2,
    "Group": 18,
    "Phase": "gas",
    "Most Stable Crystal": "",
    "Type": "Noble Gas",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": 21.5645,
    "Density": 0.0008999,
    "Melting Point (K)": 24.703,
    "Boiling Point (K)": 27.07,
    "Isotopes": 8,
    "Discoverer": "Ramsay and Travers",
    "Year of Discovery": 1898,
    "Specific Heat Capacity": 1.03,
    "Electron Configuration": "[He] 2s2 2p6",
    "Display Row": 2,
    "Display Column": 18
  },
  {
    "Atomic Number": 11,
    "Element": "Sodium",
    "Symbol": "Na",
    "Atomic Radius": 2.2,
    "Atomic Weight": 22.98976928,
    "Period": 3,
    "Group": 1,
    "Phase": "solid",
    "Most Stable Crystal": "bcc",
    "Type": "Alkali Metal",
    "Ionic Radius": 1,
    "Electronegativity": 0.93,
    "First Ionization Potential": 5.1391,
    "Density": 0.971,
    "Melting Point (K)": 371.15,
    "Boiling Point (K)": 1156,
    "Isotopes": 7,
    "Discoverer": "Davy",
    "Year of Discovery": 1807,
    "Specific Heat Capacity": 1.228,
    "Electron Configuration": "[Ne] 3s1",
    "Display Row": 3,
    "Display Column": 1
  },
  {
    "Atomic Number": 12,
    "Element": "Magnesium",
    "Symbol": "Mg",
    "Atomic Radius": 1.7,
    "Atomic Weight": 24.305,
    "Period": 3,
    "Group": 2,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Alkaline Earth Metal",
    "Ionic Radius": 0.72,
    "Electronegativity": 1.31,
    "First Ionization Potential": 7.6462,
    "Density": 1.738,
    "Melting Point (K)": 923.15,
    "Boiling Point (K)": 1363,
    "Isotopes": 8,
    "Discoverer": "Black",
    "Year of Discovery": 1755,
    "Specific Heat Capacity": 1.023,
    "Electron Configuration": "[Ne] 3s2",
    "Display Row": 3,
    "Display Column": 2
  },
  {
    "Atomic Number": 13,
    "Element": "Aluminum",
    "Symbol": "Al",
    "Atomic Radius": 1.8,
    "Atomic Weight": 26.9815386,
    "Period": 3,
    "Group": 13,
    "Phase": "solid",
    "Most Stable Crystal": "fcc",
    "Type": "Metal",
    "Ionic Radius": 0.54,
    "Electronegativity": 1.61,
    "First Ionization Potential": 5.9858,
    "Density": 2.698,
    "Melting Point (K)": 933.4,
    "Boiling Point (K)": 2792,
    "Isotopes": 8,
    "Discoverer": "W�hler",
    "Year of Discovery": 1827,
    "Specific Heat Capacity": 0.897,
    "Electron Configuration": "[Ne] 3s2 3p1",
    "Display Row": 3,
    "Display Column": 13
  },
  {
    "Atomic Number": 14,
    "Element": "Silicon",
    "Symbol": "Si",
    "Atomic Radius": 1.5,
    "Atomic Weight": 28.0855,
    "Period": 3,
    "Group": 14,
    "Phase": "solid",
    "Most Stable Crystal": "fcc",
    "Type": "Metalloid",
    "Ionic Radius": 0.4,
    "Electronegativity": 1.9,
    "First Ionization Potential": 8.1517,
    "Density": 2.3296,
    "Melting Point (K)": 1683.15,
    "Boiling Point (K)": 3538,
    "Isotopes": 8,
    "Discoverer": "Berzelius",
    "Year of Discovery": 1824,
    "Specific Heat Capacity": 0.705,
    "Electron Configuration": "[Ne] 3s2 3p2",
    "Display Row": 3,
    "Display Column": 14
  },
  {
    "Atomic Number": 15,
    "Element": "Phosphorus",
    "Symbol": "P",
    "Atomic Radius": 1.2,
    "Atomic Weight": 30.973762,
    "Period": 3,
    "Group": 15,
    "Phase": "solid",
    "Most Stable Crystal": "cub",
    "Type": "Nonmetal",
    "Ionic Radius": 0.38,
    "Electronegativity": 2.19,
    "First Ionization Potential": 10.4867,
    "Density": 1.82,
    "Melting Point (K)": 317.25,
    "Boiling Point (K)": 553,
    "Isotopes": 7,
    "Discoverer": "BranBrand",
    "Year of Discovery": 1669,
    "Specific Heat Capacity": 0.769,
    "Electron Configuration": "[Ne] 3s2 3p3",
    "Display Row": 3,
    "Display Column": 15
  },
  {
    "Atomic Number": 16,
    "Element": "Sulfur",
    "Symbol": "S",
    "Atomic Radius": 1.1,
    "Atomic Weight": 32.065,
    "Period": 3,
    "Group": 16,
    "Phase": "solid",
    "Most Stable Crystal": "orth",
    "Type": "Nonmetal",
    "Ionic Radius": 0.37,
    "Electronegativity": 2.58,
    "First Ionization Potential": 10.36,
    "Density": 2.067,
    "Melting Point (K)": 388.51,
    "Boiling Point (K)": 717.8,
    "Isotopes": 10,
    "Discoverer": "Prehistoric",
    "Year of Discovery": "",
    "Specific Heat Capacity": 0.71,
    "Electron Configuration": "[Ne] 3s2 3p4",
    "Display Row": 3,
    "Display Column": 16
  },
  {
    "Atomic Number": 17,
    "Element": "Chlorine",
    "Symbol": "Cl",
    "Atomic Radius": 0.97,
    "Atomic Weight": 35.453,
    "Period": 3,
    "Group": 17,
    "Phase": "gas",
    "Most Stable Crystal": "",
    "Type": "Halogen",
    "Ionic Radius": 1.8,
    "Electronegativity": 3.16,
    "First Ionization Potential": 12.9676,
    "Density": 0.003214,
    "Melting Point (K)": 172.31,
    "Boiling Point (K)": 239.11,
    "Isotopes": 11,
    "Discoverer": "Scheele",
    "Year of Discovery": 1774,
    "Specific Heat Capacity": 0.479,
    "Electron Configuration": "[Ne] 3s2 3p5",
    "Display Row": 3,
    "Display Column": 17
  },
  {
    "Atomic Number": 18,
    "Element": "Argon",
    "Symbol": "Ar",
    "Atomic Radius": 0.88,
    "Atomic Weight": 39.948,
    "Period": 3,
    "Group": 18,
    "Phase": "gas",
    "Most Stable Crystal": "",
    "Type": "Noble Gas",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": 15.7596,
    "Density": 0.0017837,
    "Melting Point (K)": 83.96,
    "Boiling Point (K)": 87.3,
    "Isotopes": 8,
    "Discoverer": "Rayleigh and Ramsay",
    "Year of Discovery": 1894,
    "Specific Heat Capacity": 0.52,
    "Electron Configuration": "[Ne] 3s2 3p6",
    "Display Row": 3,
    "Display Column": 18
  },
  {
    "Atomic Number": 19,
    "Element": "Potassium",
    "Symbol": "K",
    "Atomic Radius": 2.8,
    "Atomic Weight": 39.0983,
    "Period": 4,
    "Group": 1,
    "Phase": "solid",
    "Most Stable Crystal": "bcc",
    "Type": "Alkali Metal",
    "Ionic Radius": 1.4,
    "Electronegativity": 0.82,
    "First Ionization Potential": 4.3407,
    "Density": 0.862,
    "Melting Point (K)": 336.5,
    "Boiling Point (K)": 1032,
    "Isotopes": 10,
    "Discoverer": "Davy",
    "Year of Discovery": 1807,
    "Specific Heat Capacity": 0.757,
    "Electron Configuration": "[Ar] 4s1",
    "Display Row": 4,
    "Display Column": 1
  },
  {
    "Atomic Number": 20,
    "Element": "Calcium",
    "Symbol": "Ca",
    "Atomic Radius": 2.2,
    "Atomic Weight": 40.078,
    "Period": 4,
    "Group": 2,
    "Phase": "solid",
    "Most Stable Crystal": "fcc",
    "Type": "Alkaline Earth Metal",
    "Ionic Radius": 0.99,
    "Electronegativity": 1,
    "First Ionization Potential": 6.1132,
    "Density": 1.54,
    "Melting Point (K)": 1112.15,
    "Boiling Point (K)": 1757,
    "Isotopes": 14,
    "Discoverer": "Davy",
    "Year of Discovery": 1808,
    "Specific Heat Capacity": 0.647,
    "Electron Configuration": "[Ar] 4s2",
    "Display Row": 4,
    "Display Column": 2
  },
  {
    "Atomic Number": 21,
    "Element": "Scandium",
    "Symbol": "Sc",
    "Atomic Radius": 2.1,
    "Atomic Weight": 44.955912,
    "Period": 4,
    "Group": 3,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Transition Metal",
    "Ionic Radius": 0.75,
    "Electronegativity": 1.36,
    "First Ionization Potential": 6.5615,
    "Density": 2.989,
    "Melting Point (K)": 1812.15,
    "Boiling Point (K)": 3109,
    "Isotopes": 15,
    "Discoverer": "Nilson",
    "Year of Discovery": 1878,
    "Specific Heat Capacity": 0.568,
    "Electron Configuration": "[Ar] 3d1 4s2",
    "Display Row": 4,
    "Display Column": 3
  },
  {
    "Atomic Number": 22,
    "Element": "Titanium",
    "Symbol": "Ti",
    "Atomic Radius": 2,
    "Atomic Weight": 47.867,
    "Period": 4,
    "Group": 4,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Transition Metal",
    "Ionic Radius": 0.61,
    "Electronegativity": 1.54,
    "First Ionization Potential": 6.8281,
    "Density": 4.54,
    "Melting Point (K)": 1933.15,
    "Boiling Point (K)": 3560,
    "Isotopes": 9,
    "Discoverer": "Gregor",
    "Year of Discovery": 1791,
    "Specific Heat Capacity": 0.523,
    "Electron Configuration": "[Ar] 3d2 4s2",
    "Display Row": 4,
    "Display Column": 4
  },
  {
    "Atomic Number": 23,
    "Element": "Vanadium",
    "Symbol": "V",
    "Atomic Radius": 1.9,
    "Atomic Weight": 50.9415,
    "Period": 4,
    "Group": 5,
    "Phase": "solid",
    "Most Stable Crystal": "bcc",
    "Type": "Transition Metal",
    "Ionic Radius": 0.59,
    "Electronegativity": 1.63,
    "First Ionization Potential": 6.7462,
    "Density": 6.11,
    "Melting Point (K)": 2175.15,
    "Boiling Point (K)": 3680,
    "Isotopes": 9,
    "Discoverer": "del Rio",
    "Year of Discovery": 1801,
    "Specific Heat Capacity": 0.489,
    "Electron Configuration": "[Ar] 3d3 4s2",
    "Display Row": 4,
    "Display Column": 5
  },
  {
    "Atomic Number": 24,
    "Element": "Chromium",
    "Symbol": "Cr",
    "Atomic Radius": 1.9,
    "Atomic Weight": 51.9961,
    "Period": 4,
    "Group": 6,
    "Phase": "solid",
    "Most Stable Crystal": "bcc",
    "Type": "Transition Metal",
    "Ionic Radius": 0.52,
    "Electronegativity": 1.66,
    "First Ionization Potential": 6.7665,
    "Density": 7.15,
    "Melting Point (K)": 2130.15,
    "Boiling Point (K)": 2944,
    "Isotopes": 9,
    "Discoverer": "Vauquelin",
    "Year of Discovery": 1797,
    "Specific Heat Capacity": 0.449,
    "Electron Configuration": "[Ar] 3d5 4s1",
    "Display Row": 4,
    "Display Column": 6
  },
  {
    "Atomic Number": 25,
    "Element": "Manganese",
    "Symbol": "Mn",
    "Atomic Radius": 1.8,
    "Atomic Weight": 54.938045,
    "Period": 4,
    "Group": 7,
    "Phase": "solid",
    "Most Stable Crystal": "bcc",
    "Type": "Transition Metal",
    "Ionic Radius": 0.46,
    "Electronegativity": 1.55,
    "First Ionization Potential": 7.434,
    "Density": 7.44,
    "Melting Point (K)": 1519.15,
    "Boiling Point (K)": 2334,
    "Isotopes": 11,
    "Discoverer": "Gahn, Scheele",
    "Year of Discovery": 1774,
    "Specific Heat Capacity": 0.479,
    "Electron Configuration": "[Ar] 3d5 4s2",
    "Display Row": 4,
    "Display Column": 7
  },
  {
    "Atomic Number": 26,
    "Element": "Iron",
    "Symbol": "Fe",
    "Atomic Radius": 1.7,
    "Atomic Weight": 55.845,
    "Period": 4,
    "Group": 8,
    "Phase": "solid",
    "Most Stable Crystal": "bcc",
    "Type": "Transition Metal",
    "Ionic Radius": 0.65,
    "Electronegativity": 1.83,
    "First Ionization Potential": 7.9024,
    "Density": 7.874,
    "Melting Point (K)": 1808.15,
    "Boiling Point (K)": 3134,
    "Isotopes": 10,
    "Discoverer": "Prehistoric",
    "Year of Discovery": "",
    "Specific Heat Capacity": 0.449,
    "Electron Configuration": "[Ar] 3d6 4s2",
    "Display Row": 4,
    "Display Column": 8
  },
  {
    "Atomic Number": 27,
    "Element": "Cobalt",
    "Symbol": "Co",
    "Atomic Radius": 1.7,
    "Atomic Weight": 58.933195,
    "Period": 4,
    "Group": 9,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Transition Metal",
    "Ionic Radius": 0.75,
    "Electronegativity": 1.88,
    "First Ionization Potential": 7.881,
    "Density": 8.86,
    "Melting Point (K)": 1768.15,
    "Boiling Point (K)": 3200,
    "Isotopes": 14,
    "Discoverer": "Brandt",
    "Year of Discovery": 1735,
    "Specific Heat Capacity": 0.421,
    "Electron Configuration": "[Ar] 3d7 4s2",
    "Display Row": 4,
    "Display Column": 9
  },
  {
    "Atomic Number": 28,
    "Element": "Nickel",
    "Symbol": "Ni",
    "Atomic Radius": 1.6,
    "Atomic Weight": 58.6934,
    "Period": 4,
    "Group": 10,
    "Phase": "solid",
    "Most Stable Crystal": "fcc",
    "Type": "Transition Metal",
    "Ionic Radius": 0.69,
    "Electronegativity": 1.91,
    "First Ionization Potential": 7.6398,
    "Density": 8.912,
    "Melting Point (K)": 1726.15,
    "Boiling Point (K)": 3186,
    "Isotopes": 11,
    "Discoverer": "Cronstedt",
    "Year of Discovery": 1751,
    "Specific Heat Capacity": 0.444,
    "Electron Configuration": "[Ar] 3d8 4s2",
    "Display Row": 4,
    "Display Column": 10
  },
  {
    "Atomic Number": 29,
    "Element": "Copper",
    "Symbol": "Cu",
    "Atomic Radius": 1.6,
    "Atomic Weight": 63.546,
    "Period": 4,
    "Group": 11,
    "Phase": "solid",
    "Most Stable Crystal": "fcc",
    "Type": "Transition Metal",
    "Ionic Radius": 0.73,
    "Electronegativity": 1.9,
    "First Ionization Potential": 7.7264,
    "Density": 8.96,
    "Melting Point (K)": 1357.75,
    "Boiling Point (K)": 2835,
    "Isotopes": 11,
    "Discoverer": "Prehistoric",
    "Year of Discovery": "",
    "Specific Heat Capacity": 0.385,
    "Electron Configuration": "[Ar] 3d10 4s1",
    "Display Row": 4,
    "Display Column": 11
  },
  {
    "Atomic Number": 30,
    "Element": "Zinc",
    "Symbol": "Zn",
    "Atomic Radius": 1.5,
    "Atomic Weight": 65.38,
    "Period": 4,
    "Group": 12,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Transition Metal",
    "Ionic Radius": 0.74,
    "Electronegativity": 1.65,
    "First Ionization Potential": 9.3942,
    "Density": 7.134,
    "Melting Point (K)": 692.88,
    "Boiling Point (K)": 1180,
    "Isotopes": 15,
    "Discoverer": "Prehistoric",
    "Year of Discovery": "",
    "Specific Heat Capacity": 0.388,
    "Electron Configuration": "[Ar] 3d10 4s2",
    "Display Row": 4,
    "Display Column": 12
  },
  {
    "Atomic Number": 31,
    "Element": "Gallium",
    "Symbol": "Ga",
    "Atomic Radius": 1.8,
    "Atomic Weight": 69.723,
    "Period": 4,
    "Group": 13,
    "Phase": "solid",
    "Most Stable Crystal": "orth",
    "Type": "Metal",
    "Ionic Radius": 0.62,
    "Electronegativity": 1.81,
    "First Ionization Potential": 5.9993,
    "Density": 5.907,
    "Melting Point (K)": 302.91,
    "Boiling Point (K)": 2477,
    "Isotopes": 14,
    "Discoverer": "de Boisbaudran",
    "Year of Discovery": 1875,
    "Specific Heat Capacity": 0.371,
    "Electron Configuration": "[Ar] 3d10 4s2 4p1",
    "Display Row": 4,
    "Display Column": 13
  },
  {
    "Atomic Number": 32,
    "Element": "Germanium",
    "Symbol": "Ge",
    "Atomic Radius": 1.5,
    "Atomic Weight": 72.64,
    "Period": 4,
    "Group": 14,
    "Phase": "solid",
    "Most Stable Crystal": "fcc",
    "Type": "Metalloid",
    "Ionic Radius": 0.53,
    "Electronegativity": 2.01,
    "First Ionization Potential": 7.8994,
    "Density": 5.323,
    "Melting Point (K)": 1211.45,
    "Boiling Point (K)": 3106,
    "Isotopes": 17,
    "Discoverer": "Winkler",
    "Year of Discovery": 1886,
    "Specific Heat Capacity": 0.32,
    "Electron Configuration": "[Ar] 3d10 4s2 4p2",
    "Display Row": 4,
    "Display Column": 14
  },
  {
    "Atomic Number": 33,
    "Element": "Arsenic",
    "Symbol": "As",
    "Atomic Radius": 1.3,
    "Atomic Weight": 74.9216,
    "Period": 4,
    "Group": 15,
    "Phase": "solid",
    "Most Stable Crystal": "rho",
    "Type": "Metalloid",
    "Ionic Radius": 0.58,
    "Electronegativity": 2.18,
    "First Ionization Potential": 9.7886,
    "Density": 5.776,
    "Melting Point (K)": 1090.15,
    "Boiling Point (K)": 887,
    "Isotopes": 14,
    "Discoverer": "Albertus Magnus",
    "Year of Discovery": 1250,
    "Specific Heat Capacity": 0.329,
    "Electron Configuration": "[Ar] 3d10 4s2 4p3",
    "Display Row": 4,
    "Display Column": 15
  },
  {
    "Atomic Number": 34,
    "Element": "Selenium",
    "Symbol": "Se",
    "Atomic Radius": 1.2,
    "Atomic Weight": 78.96,
    "Period": 4,
    "Group": 16,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Nonmetal",
    "Ionic Radius": 0.5,
    "Electronegativity": 2.55,
    "First Ionization Potential": 9.7524,
    "Density": 4.809,
    "Melting Point (K)": 494.15,
    "Boiling Point (K)": 958,
    "Isotopes": 20,
    "Discoverer": "Berzelius",
    "Year of Discovery": 1817,
    "Specific Heat Capacity": 0.321,
    "Electron Configuration": "[Ar] 3d10 4s2 4p4",
    "Display Row": 4,
    "Display Column": 16
  },
  {
    "Atomic Number": 35,
    "Element": "Bromine",
    "Symbol": "Br",
    "Atomic Radius": 1.1,
    "Atomic Weight": 79.904,
    "Period": 4,
    "Group": 17,
    "Phase": "liq",
    "Most Stable Crystal": "",
    "Type": "Halogen",
    "Ionic Radius": 2,
    "Electronegativity": 2.96,
    "First Ionization Potential": 11.8138,
    "Density": 3.122,
    "Melting Point (K)": 266.05,
    "Boiling Point (K)": 332,
    "Isotopes": 19,
    "Discoverer": "Balard",
    "Year of Discovery": 1826,
    "Specific Heat Capacity": 0.474,
    "Electron Configuration": "[Ar] 3d10 4s2 4p5",
    "Display Row": 4,
    "Display Column": 17
  },
  {
    "Atomic Number": 36,
    "Element": "Krypton",
    "Symbol": "Kr",
    "Atomic Radius": 1,
    "Atomic Weight": 83.798,
    "Period": 4,
    "Group": 18,
    "Phase": "gas",
    "Most Stable Crystal": "",
    "Type": "Noble Gas",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": 13.9996,
    "Density": 0.003733,
    "Melting Point (K)": 115.93,
    "Boiling Point (K)": 119.93,
    "Isotopes": 23,
    "Discoverer": "Ramsay and Travers",
    "Year of Discovery": 1898,
    "Specific Heat Capacity": 0.248,
    "Electron Configuration": "[Ar] 3d10 4s2 4p6",
    "Display Row": 4,
    "Display Column": 18
  },
  {
    "Atomic Number": 37,
    "Element": "Rubidium",
    "Symbol": "Rb",
    "Atomic Radius": 3,
    "Atomic Weight": 85.4678,
    "Period": 5,
    "Group": 1,
    "Phase": "solid",
    "Most Stable Crystal": "bcc",
    "Type": "Alkali Metal",
    "Ionic Radius": 1.5,
    "Electronegativity": 0.82,
    "First Ionization Potential": 4.1771,
    "Density": 1.532,
    "Melting Point (K)": 312.79,
    "Boiling Point (K)": 961,
    "Isotopes": 20,
    "Discoverer": "Bunsen and Kirchoff",
    "Year of Discovery": 1861,
    "Specific Heat Capacity": 0.363,
    "Electron Configuration": "[Kr] 5s1",
    "Display Row": 5,
    "Display Column": 1
  },
  {
    "Atomic Number": 38,
    "Element": "Strontium",
    "Symbol": "Sr",
    "Atomic Radius": 2.5,
    "Atomic Weight": 87.62,
    "Period": 5,
    "Group": 2,
    "Phase": "solid",
    "Most Stable Crystal": "fcc",
    "Type": "Alkaline Earth Metal",
    "Ionic Radius": 1.1,
    "Electronegativity": 0.95,
    "First Ionization Potential": 5.6949,
    "Density": 2.64,
    "Melting Point (K)": 1042.15,
    "Boiling Point (K)": 1655,
    "Isotopes": 18,
    "Discoverer": "Davy",
    "Year of Discovery": 1808,
    "Specific Heat Capacity": 0.301,
    "Electron Configuration": "[Kr] 5s2",
    "Display Row": 5,
    "Display Column": 2
  },
  {
    "Atomic Number": 39,
    "Element": "Yttrium",
    "Symbol": "Y",
    "Atomic Radius": 2.3,
    "Atomic Weight": 88.90585,
    "Period": 5,
    "Group": 3,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Transition Metal",
    "Ionic Radius": 0.9,
    "Electronegativity": 1.22,
    "First Ionization Potential": 6.2173,
    "Density": 4.469,
    "Melting Point (K)": 1799.15,
    "Boiling Point (K)": 3609,
    "Isotopes": 21,
    "Discoverer": "Gadolin",
    "Year of Discovery": 1794,
    "Specific Heat Capacity": 0.298,
    "Electron Configuration": "[Kr] 4d1 5s2",
    "Display Row": 5,
    "Display Column": 3
  },
  {
    "Atomic Number": 40,
    "Element": "Zirconium",
    "Symbol": "Zr",
    "Atomic Radius": 2.2,
    "Atomic Weight": 91.224,
    "Period": 5,
    "Group": 4,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Transition Metal",
    "Ionic Radius": 0.72,
    "Electronegativity": 1.33,
    "First Ionization Potential": 6.6339,
    "Density": 6.506,
    "Melting Point (K)": 2125.15,
    "Boiling Point (K)": 4682,
    "Isotopes": 20,
    "Discoverer": "Klaproth",
    "Year of Discovery": 1789,
    "Specific Heat Capacity": 0.278,
    "Electron Configuration": "[Kr] 4d2 5s2",
    "Display Row": 5,
    "Display Column": 4
  },
  {
    "Atomic Number": 41,
    "Element": "Niobium",
    "Symbol": "Nb",
    "Atomic Radius": 2.1,
    "Atomic Weight": 92.90638,
    "Period": 5,
    "Group": 5,
    "Phase": "solid",
    "Most Stable Crystal": "bcc",
    "Type": "Transition Metal",
    "Ionic Radius": 0.69,
    "Electronegativity": 1.6,
    "First Ionization Potential": 6.7589,
    "Density": 8.57,
    "Melting Point (K)": 2741.15,
    "Boiling Point (K)": 5017,
    "Isotopes": 24,
    "Discoverer": "Hatchett",
    "Year of Discovery": 1801,
    "Specific Heat Capacity": 0.265,
    "Electron Configuration": "[Kr] 4d4 5s1",
    "Display Row": 5,
    "Display Column": 5
  },
  {
    "Atomic Number": 42,
    "Element": "Molybdenum",
    "Symbol": "Mo",
    "Atomic Radius": 2,
    "Atomic Weight": 95.96,
    "Period": 5,
    "Group": 6,
    "Phase": "solid",
    "Most Stable Crystal": "bcc",
    "Type": "Transition Metal",
    "Ionic Radius": 0.65,
    "Electronegativity": 2.16,
    "First Ionization Potential": 7.0924,
    "Density": 10.22,
    "Melting Point (K)": 2890.15,
    "Boiling Point (K)": 4912,
    "Isotopes": 20,
    "Discoverer": "Scheele",
    "Year of Discovery": 1778,
    "Specific Heat Capacity": 0.251,
    "Electron Configuration": "[Kr] 4d5 5s1",
    "Display Row": 5,
    "Display Column": 6
  },
  {
    "Atomic Number": 43,
    "Element": "Technetium",
    "Symbol": "Tc",
    "Atomic Radius": 2,
    "Atomic Weight": 98,
    "Period": 5,
    "Group": 7,
    "Phase": "artificial",
    "Most Stable Crystal": "hex",
    "Type": "Transition Metal",
    "Ionic Radius": 0.56,
    "Electronegativity": 1.9,
    "First Ionization Potential": 7.28,
    "Density": 11.5,
    "Melting Point (K)": 2473.15,
    "Boiling Point (K)": 5150,
    "Isotopes": 23,
    "Discoverer": "Perrier and Segr�",
    "Year of Discovery": 1937,
    "Specific Heat Capacity": "",
    "Electron Configuration": "[Kr] 4d5 5s2",
    "Display Row": 5,
    "Display Column": 7
  },
  {
    "Atomic Number": 44,
    "Element": "Ruthenium",
    "Symbol": "Ru",
    "Atomic Radius": 1.9,
    "Atomic Weight": 101.07,
    "Period": 5,
    "Group": 8,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Transition Metal",
    "Ionic Radius": 0.68,
    "Electronegativity": 2.2,
    "First Ionization Potential": 7.3605,
    "Density": 12.37,
    "Melting Point (K)": 2523.15,
    "Boiling Point (K)": 4423,
    "Isotopes": 16,
    "Discoverer": "Klaus",
    "Year of Discovery": 1844,
    "Specific Heat Capacity": 0.238,
    "Electron Configuration": "[Kr] 4d7 5s1",
    "Display Row": 5,
    "Display Column": 8
  },
  {
    "Atomic Number": 45,
    "Element": "Rhodium",
    "Symbol": "Rh",
    "Atomic Radius": 1.8,
    "Atomic Weight": 102.9055,
    "Period": 5,
    "Group": 9,
    "Phase": "solid",
    "Most Stable Crystal": "fcc",
    "Type": "Transition Metal",
    "Ionic Radius": 0.68,
    "Electronegativity": 2.28,
    "First Ionization Potential": 7.4589,
    "Density": 12.41,
    "Melting Point (K)": 2239.15,
    "Boiling Point (K)": 3968,
    "Isotopes": 20,
    "Discoverer": "Wollaston",
    "Year of Discovery": 1803,
    "Specific Heat Capacity": 0.243,
    "Electron Configuration": "[Kr] 4d8 5s1",
    "Display Row": 5,
    "Display Column": 9
  },
  {
    "Atomic Number": 46,
    "Element": "Palladium",
    "Symbol": "Pd",
    "Atomic Radius": 1.8,
    "Atomic Weight": 106.42,
    "Period": 5,
    "Group": 10,
    "Phase": "solid",
    "Most Stable Crystal": "fcc",
    "Type": "Transition Metal",
    "Ionic Radius": 0.86,
    "Electronegativity": 2.2,
    "First Ionization Potential": 8.3369,
    "Density": 12.02,
    "Melting Point (K)": 1825.15,
    "Boiling Point (K)": 3236,
    "Isotopes": 21,
    "Discoverer": "Wollaston",
    "Year of Discovery": 1803,
    "Specific Heat Capacity": 0.244,
    "Electron Configuration": "[Kr] 4d10",
    "Display Row": 5,
    "Display Column": 10
  },
  {
    "Atomic Number": 47,
    "Element": "Silver",
    "Symbol": "Ag",
    "Atomic Radius": 1.8,
    "Atomic Weight": 107.8682,
    "Period": 5,
    "Group": 11,
    "Phase": "solid",
    "Most Stable Crystal": "fcc",
    "Type": "Transition Metal",
    "Ionic Radius": 1.3,
    "Electronegativity": 1.93,
    "First Ionization Potential": 7.5762,
    "Density": 10.501,
    "Melting Point (K)": 1234.15,
    "Boiling Point (K)": 2435,
    "Isotopes": 27,
    "Discoverer": "Prehistoric",
    "Year of Discovery": "",
    "Specific Heat Capacity": 0.235,
    "Electron Configuration": "[Kr] 4d10 5s1",
    "Display Row": 5,
    "Display Column": 11
  },
  {
    "Atomic Number": 48,
    "Element": "Cadmium",
    "Symbol": "Cd",
    "Atomic Radius": 1.7,
    "Atomic Weight": 112.411,
    "Period": 5,
    "Group": 12,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Transition Metal",
    "Ionic Radius": 0.97,
    "Electronegativity": 1.69,
    "First Ionization Potential": 8.9938,
    "Density": 8.69,
    "Melting Point (K)": 594.33,
    "Boiling Point (K)": 1040,
    "Isotopes": 22,
    "Discoverer": "Stromeyer",
    "Year of Discovery": 1817,
    "Specific Heat Capacity": 0.232,
    "Electron Configuration": "[Kr] 4d10 5s2",
    "Display Row": 5,
    "Display Column": 12
  },
  {
    "Atomic Number": 49,
    "Element": "Indium",
    "Symbol": "In",
    "Atomic Radius": 2,
    "Atomic Weight": 114.818,
    "Period": 5,
    "Group": 13,
    "Phase": "solid",
    "Most Stable Crystal": "tet",
    "Type": "Metal",
    "Ionic Radius": 0.8,
    "Electronegativity": 1.78,
    "First Ionization Potential": 5.7864,
    "Density": 7.31,
    "Melting Point (K)": 429.91,
    "Boiling Point (K)": 2345,
    "Isotopes": 34,
    "Discoverer": "Reich and Richter",
    "Year of Discovery": 1863,
    "Specific Heat Capacity": 0.233,
    "Electron Configuration": "[Kr] 4d10 5s2 5p1",
    "Display Row": 5,
    "Display Column": 13
  },
  {
    "Atomic Number": 50,
    "Element": "Tin",
    "Symbol": "Sn",
    "Atomic Radius": 1.7,
    "Atomic Weight": 118.71,
    "Period": 5,
    "Group": 14,
    "Phase": "solid",
    "Most Stable Crystal": "tet",
    "Type": "Metal",
    "Ionic Radius": 0.69,
    "Electronegativity": 1.96,
    "First Ionization Potential": 7.3439,
    "Density": 7.287,
    "Melting Point (K)": 505.21,
    "Boiling Point (K)": 2875,
    "Isotopes": 28,
    "Discoverer": "Prehistoric",
    "Year of Discovery": "",
    "Specific Heat Capacity": 0.228,
    "Electron Configuration": "[Kr] 4d10 5s2 5p2",
    "Display Row": 5,
    "Display Column": 14
  },
  {
    "Atomic Number": 51,
    "Element": "Antimony",
    "Symbol": "Sb",
    "Atomic Radius": 1.5,
    "Atomic Weight": 121.76,
    "Period": 5,
    "Group": 15,
    "Phase": "solid",
    "Most Stable Crystal": "rho",
    "Type": "Metalloid",
    "Ionic Radius": 0.76,
    "Electronegativity": 2.05,
    "First Ionization Potential": 8.6084,
    "Density": 6.685,
    "Melting Point (K)": 904.05,
    "Boiling Point (K)": 1860,
    "Isotopes": 29,
    "Discoverer": "Early historic times",
    "Year of Discovery": "",
    "Specific Heat Capacity": 0.207,
    "Electron Configuration": "[Kr] 4d10 5s2 5p3",
    "Display Row": 5,
    "Display Column": 15
  },
  {
    "Atomic Number": 52,
    "Element": "Tellurium",
    "Symbol": "Te",
    "Atomic Radius": 1.4,
    "Atomic Weight": 127.6,
    "Period": 5,
    "Group": 16,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Metalloid",
    "Ionic Radius": 0.97,
    "Electronegativity": 2.1,
    "First Ionization Potential": 9.0096,
    "Density": 6.232,
    "Melting Point (K)": 722.8,
    "Boiling Point (K)": 1261,
    "Isotopes": 29,
    "Discoverer": "von Reichenstein",
    "Year of Discovery": 1782,
    "Specific Heat Capacity": 0.202,
    "Electron Configuration": "[Kr] 4d10 5s2 5p4",
    "Display Row": 5,
    "Display Column": 16
  },
  {
    "Atomic Number": 53,
    "Element": "Iodine",
    "Symbol": "I",
    "Atomic Radius": 1.3,
    "Atomic Weight": 126.90447,
    "Period": 5,
    "Group": 17,
    "Phase": "solid",
    "Most Stable Crystal": "orth",
    "Type": "Halogen",
    "Ionic Radius": 2.2,
    "Electronegativity": 2.66,
    "First Ionization Potential": 10.4513,
    "Density": 4.93,
    "Melting Point (K)": 386.65,
    "Boiling Point (K)": 457.4,
    "Isotopes": 24,
    "Discoverer": "Courtois",
    "Year of Discovery": 1811,
    "Specific Heat Capacity": 0.214,
    "Electron Configuration": "[Kr] 4d10 5s2 5p5",
    "Display Row": 5,
    "Display Column": 17
  },
  {
    "Atomic Number": 54,
    "Element": "Xenon",
    "Symbol": "Xe",
    "Atomic Radius": 1.2,
    "Atomic Weight": 131.293,
    "Period": 5,
    "Group": 18,
    "Phase": "gas",
    "Most Stable Crystal": "gas",
    "Type": "Noble Gas",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": 12.1298,
    "Density": 0.005887,
    "Melting Point (K)": 161.45,
    "Boiling Point (K)": 165.03,
    "Isotopes": 31,
    "Discoverer": "Ramsay and Travers",
    "Year of Discovery": 1898,
    "Specific Heat Capacity": 0.158,
    "Electron Configuration": "[Kr] 4d10 5s2 5p6",
    "Display Row": 5,
    "Display Column": 18
  },
  {
    "Atomic Number": 55,
    "Element": "Cesium",
    "Symbol": "Cs",
    "Atomic Radius": 3.3,
    "Atomic Weight": 132.9054519,
    "Period": 6,
    "Group": 1,
    "Phase": "solid",
    "Most Stable Crystal": "",
    "Type": "Alkali Metal",
    "Ionic Radius": 1.7,
    "Electronegativity": 0.79,
    "First Ionization Potential": 3.8939,
    "Density": 1.873,
    "Melting Point (K)": 301.7,
    "Boiling Point (K)": 944,
    "Isotopes": 22,
    "Discoverer": "Bunsen and Kirchoff",
    "Year of Discovery": 1860,
    "Specific Heat Capacity": 0.242,
    "Electron Configuration": "[Xe] 6s1",
    "Display Row": 6,
    "Display Column": 1
  },
  {
    "Atomic Number": 56,
    "Element": "Barium",
    "Symbol": "Ba",
    "Atomic Radius": 2.8,
    "Atomic Weight": 137.327,
    "Period": 6,
    "Group": 2,
    "Phase": "solid",
    "Most Stable Crystal": "bcc",
    "Type": "Alkaline Earth Metal",
    "Ionic Radius": 1.4,
    "Electronegativity": 0.89,
    "First Ionization Potential": 5.2117,
    "Density": 3.594,
    "Melting Point (K)": 1002.15,
    "Boiling Point (K)": 2170,
    "Isotopes": 25,
    "Discoverer": "Davy",
    "Year of Discovery": 1808,
    "Specific Heat Capacity": 0.204,
    "Electron Configuration": "[Xe] 6s2",
    "Display Row": 6,
    "Display Column": 2
  },
  {
    "Atomic Number": 57,
    "Element": "Lanthanum",
    "Symbol": "La",
    "Atomic Radius": 2.7,
    "Atomic Weight": 138.90547,
    "Period": 6,
    "Group": 3,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Lanthanide",
    "Ionic Radius": 1.1,
    "Electronegativity": 1.1,
    "First Ionization Potential": 5.5769,
    "Density": 6.145,
    "Melting Point (K)": 1193.15,
    "Boiling Point (K)": 3737,
    "Isotopes": 19,
    "Discoverer": "Mosander",
    "Year of Discovery": 1839,
    "Specific Heat Capacity": 0.195,
    "Electron Configuration": "[Xe] 5d1 6s2",
    "Display Row": 8,
    "Display Column": 3
  },
  {
    "Atomic Number": 58,
    "Element": "Cerium",
    "Symbol": "Ce",
    "Atomic Radius": 2.7,
    "Atomic Weight": 140.116,
    "Period": 6,
    "Group": 19,
    "Phase": "solid",
    "Most Stable Crystal": "fcc",
    "Type": "Lanthanide",
    "Ionic Radius": 1,
    "Electronegativity": 1.12,
    "First Ionization Potential": 5.5387,
    "Density": 6.77,
    "Melting Point (K)": 1071.15,
    "Boiling Point (K)": 3716,
    "Isotopes": 19,
    "Discoverer": "Berzelius",
    "Year of Discovery": 1803,
    "Specific Heat Capacity": 0.192,
    "Electron Configuration": "[Xe] 4f1 5d1 6s2",
    "Display Row": 8,
    "Display Column": 4
  },
  {
    "Atomic Number": 59,
    "Element": "Praseodymium",
    "Symbol": "Pr",
    "Atomic Radius": 2.7,
    "Atomic Weight": 140.90765,
    "Period": 6,
    "Group": 20,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Lanthanide",
    "Ionic Radius": 1,
    "Electronegativity": 1.13,
    "First Ionization Potential": 5.473,
    "Density": 6.773,
    "Melting Point (K)": 1204.15,
    "Boiling Point (K)": 3793,
    "Isotopes": 15,
    "Discoverer": "von Welsbach",
    "Year of Discovery": 1885,
    "Specific Heat Capacity": 0.193,
    "Electron Configuration": "[Xe] 4f3 6s2",
    "Display Row": 8,
    "Display Column": 5
  },
  {
    "Atomic Number": 60,
    "Element": "Neodymium",
    "Symbol": "Nd",
    "Atomic Radius": 2.6,
    "Atomic Weight": 144.242,
    "Period": 6,
    "Group": 21,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Lanthanide",
    "Ionic Radius": 1,
    "Electronegativity": 1.14,
    "First Ionization Potential": 5.525,
    "Density": 7.007,
    "Melting Point (K)": 1289.15,
    "Boiling Point (K)": 3347,
    "Isotopes": 16,
    "Discoverer": "von Welsbach",
    "Year of Discovery": 1885,
    "Specific Heat Capacity": 0.19,
    "Electron Configuration": "[Xe] 4f4 6s2",
    "Display Row": 8,
    "Display Column": 6
  },
  {
    "Atomic Number": 61,
    "Element": "Promethium",
    "Symbol": "Pm",
    "Atomic Radius": 2.6,
    "Atomic Weight": 145,
    "Period": 6,
    "Group": 22,
    "Phase": "artificial",
    "Most Stable Crystal": "hex",
    "Type": "Lanthanide",
    "Ionic Radius": 0.98,
    "Electronegativity": 1.13,
    "First Ionization Potential": 5.582,
    "Density": 7.26,
    "Melting Point (K)": 1204.15,
    "Boiling Point (K)": 3273,
    "Isotopes": 14,
    "Discoverer": "Marinsky et al.",
    "Year of Discovery": 1945,
    "Specific Heat Capacity": "",
    "Electron Configuration": "[Xe] 4f5 6s2",
    "Display Row": 8,
    "Display Column": 7
  },
  {
    "Atomic Number": 62,
    "Element": "Samarium",
    "Symbol": "Sm",
    "Atomic Radius": 2.6,
    "Atomic Weight": 150.36,
    "Period": 6,
    "Group": 23,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Lanthanide",
    "Ionic Radius": 0.96,
    "Electronegativity": 1.17,
    "First Ionization Potential": 5.6437,
    "Density": 7.52,
    "Melting Point (K)": 1345.15,
    "Boiling Point (K)": 2067,
    "Isotopes": 17,
    "Discoverer": "Boisbaudran",
    "Year of Discovery": 1879,
    "Specific Heat Capacity": 0.197,
    "Electron Configuration": "[Xe] 4f6 6s2",
    "Display Row": 8,
    "Display Column": 8
  },
  {
    "Atomic Number": 63,
    "Element": "Europium",
    "Symbol": "Eu",
    "Atomic Radius": 2.6,
    "Atomic Weight": 151.964,
    "Period": 6,
    "Group": 24,
    "Phase": "solid",
    "Most Stable Crystal": "bcc",
    "Type": "Lanthanide",
    "Ionic Radius": 0.95,
    "Electronegativity": 1.2,
    "First Ionization Potential": 5.6704,
    "Density": 5.243,
    "Melting Point (K)": 1095.15,
    "Boiling Point (K)": 1802,
    "Isotopes": 21,
    "Discoverer": "Demarcay",
    "Year of Discovery": 1901,
    "Specific Heat Capacity": 0.182,
    "Electron Configuration": "[Xe] 4f7 6s2",
    "Display Row": 8,
    "Display Column": 9
  },
  {
    "Atomic Number": 64,
    "Element": "Gadolinium",
    "Symbol": "Gd",
    "Atomic Radius": 2.5,
    "Atomic Weight": 157.25,
    "Period": 6,
    "Group": 25,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Lanthanide",
    "Ionic Radius": 0.94,
    "Electronegativity": 1.2,
    "First Ionization Potential": 6.1501,
    "Density": 7.895,
    "Melting Point (K)": 1585.15,
    "Boiling Point (K)": 3546,
    "Isotopes": 17,
    "Discoverer": "de Marignac",
    "Year of Discovery": 1880,
    "Specific Heat Capacity": 0.236,
    "Electron Configuration": "[Xe] 4f7 5d1 6s2",
    "Display Row": 8,
    "Display Column": 10
  },
  {
    "Atomic Number": 65,
    "Element": "Terbium",
    "Symbol": "Tb",
    "Atomic Radius": 2.5,
    "Atomic Weight": 158.92535,
    "Period": 6,
    "Group": 26,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Lanthanide",
    "Ionic Radius": 0.92,
    "Electronegativity": 1.2,
    "First Ionization Potential": 5.8638,
    "Density": 8.229,
    "Melting Point (K)": 1630.15,
    "Boiling Point (K)": 3503,
    "Isotopes": 24,
    "Discoverer": "Mosander",
    "Year of Discovery": 1843,
    "Specific Heat Capacity": 0.182,
    "Electron Configuration": "[Xe] 4f9 6s2",
    "Display Row": 8,
    "Display Column": 11
  },
  {
    "Atomic Number": 66,
    "Element": "Dysprosium",
    "Symbol": "Dy",
    "Atomic Radius": 2.5,
    "Atomic Weight": 162.5,
    "Period": 6,
    "Group": 27,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Lanthanide",
    "Ionic Radius": 0.91,
    "Electronegativity": 1.22,
    "First Ionization Potential": 5.9389,
    "Density": 8.55,
    "Melting Point (K)": 1680.15,
    "Boiling Point (K)": 2840,
    "Isotopes": 21,
    "Discoverer": "de Boisbaudran",
    "Year of Discovery": 1886,
    "Specific Heat Capacity": 0.17,
    "Electron Configuration": "[Xe] 4f10 6s2",
    "Display Row": 8,
    "Display Column": 12
  },
  {
    "Atomic Number": 67,
    "Element": "Holmium",
    "Symbol": "Ho",
    "Atomic Radius": 2.5,
    "Atomic Weight": 164.93032,
    "Period": 6,
    "Group": 28,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Lanthanide",
    "Ionic Radius": 0.9,
    "Electronegativity": 1.23,
    "First Ionization Potential": 6.0215,
    "Density": 8.795,
    "Melting Point (K)": 1743.15,
    "Boiling Point (K)": 2993,
    "Isotopes": 29,
    "Discoverer": "Delafontaine and Soret",
    "Year of Discovery": 1878,
    "Specific Heat Capacity": 0.165,
    "Electron Configuration": "[Xe] 4f11 6s2",
    "Display Row": 8,
    "Display Column": 13
  },
  {
    "Atomic Number": 68,
    "Element": "Erbium",
    "Symbol": "Er",
    "Atomic Radius": 2.5,
    "Atomic Weight": 167.259,
    "Period": 6,
    "Group": 29,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Lanthanide",
    "Ionic Radius": 0.88,
    "Electronegativity": 1.24,
    "First Ionization Potential": 6.1077,
    "Density": 9.066,
    "Melting Point (K)": 1795.15,
    "Boiling Point (K)": 3503,
    "Isotopes": 16,
    "Discoverer": "Mosander",
    "Year of Discovery": 1843,
    "Specific Heat Capacity": 0.168,
    "Electron Configuration": "[Xe] 4f12 6s2",
    "Display Row": 8,
    "Display Column": 14
  },
  {
    "Atomic Number": 69,
    "Element": "Thulium",
    "Symbol": "Tm",
    "Atomic Radius": 2.4,
    "Atomic Weight": 168.93421,
    "Period": 6,
    "Group": 30,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Lanthanide",
    "Ionic Radius": 0.87,
    "Electronegativity": 1.25,
    "First Ionization Potential": 6.1843,
    "Density": 9.321,
    "Melting Point (K)": 1818.15,
    "Boiling Point (K)": 2223,
    "Isotopes": 18,
    "Discoverer": "Cleve",
    "Year of Discovery": 1879,
    "Specific Heat Capacity": 0.16,
    "Electron Configuration": "[Xe] 4f13 6s2",
    "Display Row": 8,
    "Display Column": 15
  },
  {
    "Atomic Number": 70,
    "Element": "Ytterbium",
    "Symbol": "Yb",
    "Atomic Radius": 2.4,
    "Atomic Weight": 173.054,
    "Period": 6,
    "Group": 31,
    "Phase": "solid",
    "Most Stable Crystal": "fcc",
    "Type": "Lanthanide",
    "Ionic Radius": 0.86,
    "Electronegativity": 1.1,
    "First Ionization Potential": 6.2542,
    "Density": 6.965,
    "Melting Point (K)": 1097.15,
    "Boiling Point (K)": 1469,
    "Isotopes": 16,
    "Discoverer": "Marignac",
    "Year of Discovery": 1878,
    "Specific Heat Capacity": 0.155,
    "Electron Configuration": "[Xe] 4f14 6s2",
    "Display Row": 8,
    "Display Column": 16
  },
  {
    "Atomic Number": 71,
    "Element": "Lutetium",
    "Symbol": "Lu",
    "Atomic Radius": 2.3,
    "Atomic Weight": 174.9668,
    "Period": 6,
    "Group": 32,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Lanthanide",
    "Ionic Radius": 0.85,
    "Electronegativity": 1.27,
    "First Ionization Potential": 5.4259,
    "Density": 9.84,
    "Melting Point (K)": 1936.15,
    "Boiling Point (K)": 3675,
    "Isotopes": 22,
    "Discoverer": "Urbain/ von Welsbach",
    "Year of Discovery": 1907,
    "Specific Heat Capacity": 0.154,
    "Electron Configuration": "[Xe] 4f14 5d1 6s2",
    "Display Row": 8,
    "Display Column": 17
  },
  {
    "Atomic Number": 72,
    "Element": "Hafnium",
    "Symbol": "Hf",
    "Atomic Radius": 2.2,
    "Atomic Weight": 178.49,
    "Period": 6,
    "Group": 4,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Transition Metal",
    "Ionic Radius": 0.71,
    "Electronegativity": 1.3,
    "First Ionization Potential": 6.8251,
    "Density": 13.31,
    "Melting Point (K)": 2500.15,
    "Boiling Point (K)": 4876,
    "Isotopes": 17,
    "Discoverer": "Coster and von Hevesy",
    "Year of Discovery": 1923,
    "Specific Heat Capacity": 0.144,
    "Electron Configuration": "[Xe] 4f14 5d2 6s2",
    "Display Row": 6,
    "Display Column": 4
  },
  {
    "Atomic Number": 73,
    "Element": "Tantalum",
    "Symbol": "Ta",
    "Atomic Radius": 2.1,
    "Atomic Weight": 180.94788,
    "Period": 6,
    "Group": 5,
    "Phase": "solid",
    "Most Stable Crystal": "bcc",
    "Type": "Transition Metal",
    "Ionic Radius": 0.64,
    "Electronegativity": 1.5,
    "First Ionization Potential": 7.5496,
    "Density": 16.654,
    "Melting Point (K)": 3269.15,
    "Boiling Point (K)": 5731,
    "Isotopes": 19,
    "Discoverer": "Ekeberg",
    "Year of Discovery": 1801,
    "Specific Heat Capacity": 0.14,
    "Electron Configuration": "[Xe] 4f14 5d3 6s2",
    "Display Row": 6,
    "Display Column": 5
  },
  {
    "Atomic Number": 74,
    "Element": "Wolfram",
    "Symbol": "W",
    "Atomic Radius": 2,
    "Atomic Weight": 183.84,
    "Period": 6,
    "Group": 6,
    "Phase": "solid",
    "Most Stable Crystal": "bcc",
    "Type": "Transition Metal",
    "Ionic Radius": 0.62,
    "Electronegativity": 2.36,
    "First Ionization Potential": 7.864,
    "Density": 19.25,
    "Melting Point (K)": 3680.15,
    "Boiling Point (K)": 5828,
    "Isotopes": 22,
    "Discoverer": "J. and F. d'Elhuyar",
    "Year of Discovery": 1783,
    "Specific Heat Capacity": 0.132,
    "Electron Configuration": "[Xe] 4f14 5d4 6s2",
    "Display Row": 6,
    "Display Column": 6
  },
  {
    "Atomic Number": 75,
    "Element": "Rhenium",
    "Symbol": "Re",
    "Atomic Radius": 2,
    "Atomic Weight": 186.207,
    "Period": 6,
    "Group": 7,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Transition Metal",
    "Ionic Radius": 0.56,
    "Electronegativity": 1.9,
    "First Ionization Potential": 7.8335,
    "Density": 21.02,
    "Melting Point (K)": 3453.15,
    "Boiling Point (K)": 5869,
    "Isotopes": 21,
    "Discoverer": "Noddack, Berg, and Tacke",
    "Year of Discovery": 1925,
    "Specific Heat Capacity": 0.137,
    "Electron Configuration": "[Xe] 4f14 5d5 6s2",
    "Display Row": 6,
    "Display Column": 7
  },
  {
    "Atomic Number": 76,
    "Element": "Osmium",
    "Symbol": "Os",
    "Atomic Radius": 1.9,
    "Atomic Weight": 190.23,
    "Period": 6,
    "Group": 8,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Transition Metal",
    "Ionic Radius": 0.63,
    "Electronegativity": 2.2,
    "First Ionization Potential": 8.4382,
    "Density": 22.61,
    "Melting Point (K)": 3300.15,
    "Boiling Point (K)": 5285,
    "Isotopes": 19,
    "Discoverer": "Tennant",
    "Year of Discovery": 1803,
    "Specific Heat Capacity": 0.13,
    "Electron Configuration": "[Xe] 4f14 5d6 6s2",
    "Display Row": 6,
    "Display Column": 8
  },
  {
    "Atomic Number": 77,
    "Element": "Iridium",
    "Symbol": "Ir",
    "Atomic Radius": 1.9,
    "Atomic Weight": 192.217,
    "Period": 6,
    "Group": 9,
    "Phase": "solid",
    "Most Stable Crystal": "fcc",
    "Type": "Transition Metal",
    "Ionic Radius": 0.63,
    "Electronegativity": 2.2,
    "First Ionization Potential": 8.967,
    "Density": 22.56,
    "Melting Point (K)": 2716.15,
    "Boiling Point (K)": 4701,
    "Isotopes": 25,
    "Discoverer": "Tennant",
    "Year of Discovery": 1804,
    "Specific Heat Capacity": 0.131,
    "Electron Configuration": "[Xe] 4f14 5d7 6s2",
    "Display Row": 6,
    "Display Column": 9
  },
  {
    "Atomic Number": 78,
    "Element": "Platinum",
    "Symbol": "Pt",
    "Atomic Radius": 1.8,
    "Atomic Weight": 195.084,
    "Period": 6,
    "Group": 10,
    "Phase": "solid",
    "Most Stable Crystal": "fcc",
    "Type": "Transition Metal",
    "Ionic Radius": 0.63,
    "Electronegativity": 2.28,
    "First Ionization Potential": 8.9587,
    "Density": 21.46,
    "Melting Point (K)": 2045.15,
    "Boiling Point (K)": 4098,
    "Isotopes": 32,
    "Discoverer": "Ulloa/Wood",
    "Year of Discovery": 1735,
    "Specific Heat Capacity": 0.133,
    "Electron Configuration": "[Xe] 4f14 5d9 6s1",
    "Display Row": 6,
    "Display Column": 10
  },
  {
    "Atomic Number": 79,
    "Element": "Gold",
    "Symbol": "Au",
    "Atomic Radius": 1.8,
    "Atomic Weight": 196.966569,
    "Period": 6,
    "Group": 11,
    "Phase": "solid",
    "Most Stable Crystal": "fcc",
    "Type": "Transition Metal",
    "Ionic Radius": 0.85,
    "Electronegativity": 2.54,
    "First Ionization Potential": 9.2255,
    "Density": 19.282,
    "Melting Point (K)": 1337.73,
    "Boiling Point (K)": 3129,
    "Isotopes": 21,
    "Discoverer": "Prehistoric",
    "Year of Discovery": "",
    "Specific Heat Capacity": 0.129,
    "Electron Configuration": "[Xe] 4f14 5d10 6s1",
    "Display Row": 6,
    "Display Column": 11
  },
  {
    "Atomic Number": 80,
    "Element": "Mercury",
    "Symbol": "Hg",
    "Atomic Radius": 1.8,
    "Atomic Weight": 200.59,
    "Period": 6,
    "Group": 12,
    "Phase": "liq",
    "Most Stable Crystal": "",
    "Type": "Transition Metal",
    "Ionic Radius": 1,
    "Electronegativity": 2,
    "First Ionization Potential": 10.4375,
    "Density": 13.5336,
    "Melting Point (K)": 234.43,
    "Boiling Point (K)": 630,
    "Isotopes": 26,
    "Discoverer": "Prehistoric",
    "Year of Discovery": "",
    "Specific Heat Capacity": 0.14,
    "Electron Configuration": "[Xe] 4f14 5d10 6s2",
    "Display Row": 6,
    "Display Column": 12
  },
  {
    "Atomic Number": 81,
    "Element": "Thallium",
    "Symbol": "Tl",
    "Atomic Radius": 2.1,
    "Atomic Weight": 204.3833,
    "Period": 6,
    "Group": 13,
    "Phase": "solid",
    "Most Stable Crystal": "hex",
    "Type": "Metal",
    "Ionic Radius": 1.5,
    "Electronegativity": 2.04,
    "First Ionization Potential": 6.1082,
    "Density": 11.85,
    "Melting Point (K)": 577.15,
    "Boiling Point (K)": 1746,
    "Isotopes": 28,
    "Discoverer": "Crookes",
    "Year of Discovery": 1861,
    "Specific Heat Capacity": 0.129,
    "Electron Configuration": "[Xe] 4f14 5d10 6s2 6p1",
    "Display Row": 6,
    "Display Column": 13
  },
  {
    "Atomic Number": 82,
    "Element": "Lead",
    "Symbol": "Pb",
    "Atomic Radius": 1.8,
    "Atomic Weight": 207.2,
    "Period": 6,
    "Group": 14,
    "Phase": "solid",
    "Most Stable Crystal": "fcc",
    "Type": "Metal",
    "Ionic Radius": 1.2,
    "Electronegativity": 2.33,
    "First Ionization Potential": 7.4167,
    "Density": 11.342,
    "Melting Point (K)": 600.75,
    "Boiling Point (K)": 2022,
    "Isotopes": 29,
    "Discoverer": "Prehistoric",
    "Year of Discovery": "",
    "Specific Heat Capacity": 0.129,
    "Electron Configuration": "[Xe] 4f14 5d10 6s2 6p2",
    "Display Row": 6,
    "Display Column": 14
  },
  {
    "Atomic Number": 83,
    "Element": "Bismuth",
    "Symbol": "Bi",
    "Atomic Radius": 1.6,
    "Atomic Weight": 208.9804,
    "Period": 6,
    "Group": 15,
    "Phase": "solid",
    "Most Stable Crystal": "rho",
    "Type": "Metal",
    "Ionic Radius": 1,
    "Electronegativity": 2.02,
    "First Ionization Potential": 7.2856,
    "Density": 9.807,
    "Melting Point (K)": 544.67,
    "Boiling Point (K)": 1837,
    "Isotopes": 19,
    "Discoverer": "Geoffroy the Younger",
    "Year of Discovery": 1753,
    "Specific Heat Capacity": 0.122,
    "Electron Configuration": "[Xe] 4f14 5d10 6s2 6p3",
    "Display Row": 6,
    "Display Column": 15
  },
  {
    "Atomic Number": 84,
    "Element": "Polonium",
    "Symbol": "Po",
    "Atomic Radius": 1.5,
    "Atomic Weight": 210,
    "Period": 6,
    "Group": 16,
    "Phase": "solid",
    "Most Stable Crystal": "cub",
    "Type": "Metalloid",
    "Ionic Radius": 2.3,
    "Electronegativity": 2,
    "First Ionization Potential": 8.417,
    "Density": 9.32,
    "Melting Point (K)": 527.15,
    "Boiling Point (K)": 1235,
    "Isotopes": 34,
    "Discoverer": "Curie",
    "Year of Discovery": 1898,
    "Specific Heat Capacity": "",
    "Electron Configuration": "[Xe] 4f14 5d10 6s2 6p4",
    "Display Row": 6,
    "Display Column": 16
  },
  {
    "Atomic Number": 85,
    "Element": "Astatine",
    "Symbol": "At",
    "Atomic Radius": 1.4,
    "Atomic Weight": 210,
    "Period": 6,
    "Group": 17,
    "Phase": "solid",
    "Most Stable Crystal": "",
    "Type": "Noble Gas",
    "Ionic Radius": "",
    "Electronegativity": 2.2,
    "First Ionization Potential": 9.3,
    "Density": 7,
    "Melting Point (K)": 575.15,
    "Boiling Point (K)": 610,
    "Isotopes": 21,
    "Discoverer": "Corson et al.",
    "Year of Discovery": 1940,
    "Specific Heat Capacity": "",
    "Electron Configuration": "[Xe] 4f14 5d10 6s2 6p5",
    "Display Row": 6,
    "Display Column": 17
  },
  {
    "Atomic Number": 86,
    "Element": "Radon",
    "Symbol": "Rn",
    "Atomic Radius": 1.3,
    "Atomic Weight": 222,
    "Period": 6,
    "Group": 18,
    "Phase": "gas",
    "Most Stable Crystal": "",
    "Type": "Alkali Metal",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": 10.7485,
    "Density": 0.00973,
    "Melting Point (K)": 202.15,
    "Boiling Point (K)": 211.3,
    "Isotopes": 20,
    "Discoverer": "Dorn",
    "Year of Discovery": 1900,
    "Specific Heat Capacity": 0.094,
    "Electron Configuration": "[Xe] 4f14 5d10 6s2 6p6",
    "Display Row": 6,
    "Display Column": 18
  },
  {
    "Atomic Number": 87,
    "Element": "Francium",
    "Symbol": "Fr",
    "Atomic Radius": "",
    "Atomic Weight": 223,
    "Period": 7,
    "Group": 1,
    "Phase": "solid",
    "Most Stable Crystal": "bcc",
    "Type": "Alkaline Earth Metal",
    "Ionic Radius": 1.8,
    "Electronegativity": 0.7,
    "First Ionization Potential": 4.0727,
    "Density": 1.87,
    "Melting Point (K)": 300.15,
    "Boiling Point (K)": 950,
    "Isotopes": 21,
    "Discoverer": "Perey",
    "Year of Discovery": 1939,
    "Specific Heat Capacity": "",
    "Electron Configuration": "[Rn] 7s1",
    "Display Row": 7,
    "Display Column": 1
  },
  {
    "Atomic Number": 88,
    "Element": "Radium",
    "Symbol": "Ra",
    "Atomic Radius": "",
    "Atomic Weight": 226,
    "Period": 7,
    "Group": 2,
    "Phase": "solid",
    "Most Stable Crystal": "bcc",
    "Type": "Actinide",
    "Ionic Radius": 1.4,
    "Electronegativity": 0.9,
    "First Ionization Potential": 5.2784,
    "Density": 5.5,
    "Melting Point (K)": 973.15,
    "Boiling Point (K)": 2010,
    "Isotopes": 15,
    "Discoverer": "Pierre and Marie Curie",
    "Year of Discovery": 1898,
    "Specific Heat Capacity": "",
    "Electron Configuration": "[Rn] 7s2",
    "Display Row": 7,
    "Display Column": 2
  },
  {
    "Atomic Number": 89,
    "Element": "Actinium",
    "Symbol": "Ac",
    "Atomic Radius": "",
    "Atomic Weight": 227,
    "Period": 7,
    "Group": 3,
    "Phase": "solid",
    "Most Stable Crystal": "fcc",
    "Type": "Actinide",
    "Ionic Radius": 1.1,
    "Electronegativity": 1.1,
    "First Ionization Potential": 5.17,
    "Density": 10.07,
    "Melting Point (K)": 1323.15,
    "Boiling Point (K)": 3471,
    "Isotopes": 11,
    "Discoverer": "Debierne/Giesel",
    "Year of Discovery": 1899,
    "Specific Heat Capacity": 0.12,
    "Electron Configuration": "[Rn] 6d1 7s2",
    "Display Row": 9,
    "Display Column": 3
  },
  {
    "Atomic Number": 90,
    "Element": "Thorium",
    "Symbol": "Th",
    "Atomic Radius": "",
    "Atomic Weight": 232.03806,
    "Period": 7,
    "Group": 19,
    "Phase": "solid",
    "Most Stable Crystal": "fcc",
    "Type": "Actinide",
    "Ionic Radius": 0.97,
    "Electronegativity": 1.3,
    "First Ionization Potential": 6.3067,
    "Density": 11.72,
    "Melting Point (K)": 2028.15,
    "Boiling Point (K)": 5061,
    "Isotopes": 12,
    "Discoverer": "Berzelius",
    "Year of Discovery": 1828,
    "Specific Heat Capacity": 0.113,
    "Electron Configuration": "[Rn] 6d2 7s2",
    "Display Row": 9,
    "Display Column": 4
  },
  {
    "Atomic Number": 91,
    "Element": "Protactinium",
    "Symbol": "Pa",
    "Atomic Radius": "",
    "Atomic Weight": 231.03588,
    "Period": 7,
    "Group": 20,
    "Phase": "solid",
    "Most Stable Crystal": "orth",
    "Type": "Actinide",
    "Ionic Radius": 0.78,
    "Electronegativity": 1.5,
    "First Ionization Potential": 5.89,
    "Density": 15.37,
    "Melting Point (K)": 1873.15,
    "Boiling Point (K)": 4300,
    "Isotopes": 14,
    "Discoverer": "Hahn and Meitner",
    "Year of Discovery": 1917,
    "Specific Heat Capacity": "",
    "Electron Configuration": "[Rn] 5f2 6d1 7s2",
    "Display Row": 9,
    "Display Column": 5
  },
  {
    "Atomic Number": 92,
    "Element": "Uranium",
    "Symbol": "U",
    "Atomic Radius": "",
    "Atomic Weight": 238.02891,
    "Period": 7,
    "Group": 21,
    "Phase": "solid",
    "Most Stable Crystal": "orth",
    "Type": "Actinide",
    "Ionic Radius": 0.52,
    "Electronegativity": 1.38,
    "First Ionization Potential": 6.1941,
    "Density": 18.95,
    "Melting Point (K)": 1405.15,
    "Boiling Point (K)": 4404,
    "Isotopes": 15,
    "Discoverer": "Peligot",
    "Year of Discovery": 1841,
    "Specific Heat Capacity": 0.116,
    "Electron Configuration": "[Rn] 5f3 6d1 7s2",
    "Display Row": 9,
    "Display Column": 6
  },
  {
    "Atomic Number": 93,
    "Element": "Neptunium",
    "Symbol": "Np",
    "Atomic Radius": "",
    "Atomic Weight": 237,
    "Period": 7,
    "Group": 22,
    "Phase": "artificial",
    "Most Stable Crystal": "orth",
    "Type": "Actinide",
    "Ionic Radius": 0.75,
    "Electronegativity": 1.36,
    "First Ionization Potential": 6.2657,
    "Density": 20.45,
    "Melting Point (K)": 913.15,
    "Boiling Point (K)": 4273,
    "Isotopes": 153,
    "Discoverer": "McMillan and Abelson",
    "Year of Discovery": 1940,
    "Specific Heat Capacity": "",
    "Electron Configuration": "[Rn] 5f4 6d1 7s2",
    "Display Row": 9,
    "Display Column": 7
  },
  {
    "Atomic Number": 94,
    "Element": "Plutonium",
    "Symbol": "Pu",
    "Atomic Radius": "",
    "Atomic Weight": 244,
    "Period": 7,
    "Group": 23,
    "Phase": "artificial",
    "Most Stable Crystal": "mno",
    "Type": "Actinide",
    "Ionic Radius": 0.89,
    "Electronegativity": 1.28,
    "First Ionization Potential": 6.0262,
    "Density": 19.84,
    "Melting Point (K)": 913.15,
    "Boiling Point (K)": 3501,
    "Isotopes": 163,
    "Discoverer": "Seaborg et al.",
    "Year of Discovery": 1940,
    "Specific Heat Capacity": "",
    "Electron Configuration": "[Rn] 5f6 7s2",
    "Display Row": 9,
    "Display Column": 8
  },
  {
    "Atomic Number": 95,
    "Element": "Americium",
    "Symbol": "Am",
    "Atomic Radius": "",
    "Atomic Weight": 243,
    "Period": 7,
    "Group": 24,
    "Phase": "artificial",
    "Most Stable Crystal": "hex",
    "Type": "Actinide",
    "Ionic Radius": 0.98,
    "Electronegativity": 1.3,
    "First Ionization Potential": 5.9738,
    "Density": 13.69,
    "Melting Point (K)": 1267.15,
    "Boiling Point (K)": 2880,
    "Isotopes": 133,
    "Discoverer": "Seaborg et al.",
    "Year of Discovery": 1944,
    "Specific Heat Capacity": "",
    "Electron Configuration": "[Rn] 5f7 7s2",
    "Display Row": 9,
    "Display Column": 9
  },
  {
    "Atomic Number": 96,
    "Element": "Curium",
    "Symbol": "Cm",
    "Atomic Radius": "",
    "Atomic Weight": 247,
    "Period": 7,
    "Group": 25,
    "Phase": "artificial",
    "Most Stable Crystal": "hex",
    "Type": "Actinide",
    "Ionic Radius": 0.97,
    "Electronegativity": 1.3,
    "First Ionization Potential": 5.9915,
    "Density": 13.51,
    "Melting Point (K)": 1340.15,
    "Boiling Point (K)": 3383,
    "Isotopes": 133,
    "Discoverer": "Seaborg et al.",
    "Year of Discovery": 1944,
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 9,
    "Display Column": 10
  },
  {
    "Atomic Number": 97,
    "Element": "Berkelium",
    "Symbol": "Bk",
    "Atomic Radius": "",
    "Atomic Weight": 247,
    "Period": 7,
    "Group": 26,
    "Phase": "artificial",
    "Most Stable Crystal": "hex",
    "Type": "Actinide",
    "Ionic Radius": 0.95,
    "Electronegativity": 1.3,
    "First Ionization Potential": 6.1979,
    "Density": 14.79,
    "Melting Point (K)": 1259.15,
    "Boiling Point (K)": 983,
    "Isotopes": 83,
    "Discoverer": "Seaborg et al.",
    "Year of Discovery": 1949,
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 9,
    "Display Column": 11
  },
  {
    "Atomic Number": 98,
    "Element": "Californium",
    "Symbol": "Cf",
    "Atomic Radius": "",
    "Atomic Weight": 251,
    "Period": 7,
    "Group": 27,
    "Phase": "artificial",
    "Most Stable Crystal": "hex",
    "Type": "Actinide",
    "Ionic Radius": 0.93,
    "Electronegativity": 1.3,
    "First Ionization Potential": 6.2817,
    "Density": 15.1,
    "Melting Point (K)": 1925.15,
    "Boiling Point (K)": 1173,
    "Isotopes": 123,
    "Discoverer": "Seaborg et al.",
    "Year of Discovery": 1950,
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 9,
    "Display Column": 12
  },
  {
    "Atomic Number": 99,
    "Element": "Einsteinium",
    "Symbol": "Es",
    "Atomic Radius": "",
    "Atomic Weight": 252,
    "Period": 7,
    "Group": 28,
    "Phase": "artificial",
    "Most Stable Crystal": "hex",
    "Type": "Actinide",
    "Ionic Radius": "",
    "Electronegativity": 1.3,
    "First Ionization Potential": 6.42,
    "Density": 13.5,
    "Melting Point (K)": 1133.15,
    "Boiling Point (K)": "",
    "Isotopes": 123,
    "Discoverer": "Ghiorso et al.",
    "Year of Discovery": 1952,
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 9,
    "Display Column": 13
  },
  {
    "Atomic Number": 100,
    "Element": "Fermium",
    "Symbol": "Fm",
    "Atomic Radius": "",
    "Atomic Weight": 257,
    "Period": 7,
    "Group": 29,
    "Phase": "artificial",
    "Most Stable Crystal": "",
    "Type": "Actinide",
    "Ionic Radius": "",
    "Electronegativity": 1.3,
    "First Ionization Potential": 6.5,
    "Density": "",
    "Melting Point (K)": "",
    "Boiling Point (K)": "",
    "Isotopes": 103,
    "Discoverer": "Ghiorso et al.",
    "Year of Discovery": 1953,
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 9,
    "Display Column": 14
  },
  {
    "Atomic Number": 101,
    "Element": "Mendelevium",
    "Symbol": "Md",
    "Atomic Radius": "",
    "Atomic Weight": 258,
    "Period": 7,
    "Group": 30,
    "Phase": "artificial",
    "Most Stable Crystal": "",
    "Type": "Actinide",
    "Ionic Radius": "",
    "Electronegativity": 1.3,
    "First Ionization Potential": 6.58,
    "Density": "",
    "Melting Point (K)": "",
    "Boiling Point (K)": "",
    "Isotopes": 33,
    "Discoverer": "Ghiorso et al.",
    "Year of Discovery": 1955,
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 9,
    "Display Column": 15
  },
  {
    "Atomic Number": 102,
    "Element": "Nobelium",
    "Symbol": "No",
    "Atomic Radius": "",
    "Atomic Weight": 259,
    "Period": 7,
    "Group": 31,
    "Phase": "artificial",
    "Most Stable Crystal": "",
    "Type": "Actinide",
    "Ionic Radius": "",
    "Electronegativity": 1.3,
    "First Ionization Potential": 6.65,
    "Density": "",
    "Melting Point (K)": "",
    "Boiling Point (K)": "",
    "Isotopes": 73,
    "Discoverer": "Ghiorso et al.",
    "Year of Discovery": 1958,
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 9,
    "Display Column": 16
  },
  {
    "Atomic Number": 103,
    "Element": "Lawrencium",
    "Symbol": "Lr",
    "Atomic Radius": "",
    "Atomic Weight": 262,
    "Period": 7,
    "Group": 32,
    "Phase": "artificial",
    "Most Stable Crystal": "",
    "Type": "Actinide",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": "",
    "Density": "",
    "Melting Point (K)": "",
    "Boiling Point (K)": "",
    "Isotopes": 203,
    "Discoverer": "Ghiorso et al.",
    "Year of Discovery": 1961,
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 9,
    "Display Column": 17
  },
  {
    "Atomic Number": 104,
    "Element": "Rutherfordium",
    "Symbol": "Rf",
    "Atomic Radius": "",
    "Atomic Weight": 261,
    "Period": 7,
    "Group": 4,
    "Phase": "artificial",
    "Most Stable Crystal": "",
    "Type": "Transactinide",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": "",
    "Density": 18.1,
    "Melting Point (K)": "",
    "Boiling Point (K)": "",
    "Isotopes": "",
    "Discoverer": "Ghiorso et al.",
    "Year of Discovery": 1969,
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 7,
    "Display Column": 4
  },
  {
    "Atomic Number": 105,
    "Element": "Dubnium",
    "Symbol": "Db",
    "Atomic Radius": "",
    "Atomic Weight": 262,
    "Period": 7,
    "Group": 5,
    "Phase": "artificial",
    "Most Stable Crystal": "",
    "Type": "Transactinide",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": "",
    "Density": 39,
    "Melting Point (K)": "",
    "Boiling Point (K)": "",
    "Isotopes": "",
    "Discoverer": "Ghiorso et al.",
    "Year of Discovery": 1970,
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 7,
    "Display Column": 5
  },
  {
    "Atomic Number": 106,
    "Element": "Seaborgium",
    "Symbol": "Sg",
    "Atomic Radius": "",
    "Atomic Weight": 266,
    "Period": 7,
    "Group": 6,
    "Phase": "artificial",
    "Most Stable Crystal": "",
    "Type": "Transactinide",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": "",
    "Density": 35,
    "Melting Point (K)": "",
    "Boiling Point (K)": "",
    "Isotopes": "",
    "Discoverer": "Ghiorso et al.",
    "Year of Discovery": 1974,
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 7,
    "Display Column": 6
  },
  {
    "Atomic Number": 107,
    "Element": "Bohrium",
    "Symbol": "Bh",
    "Atomic Radius": "",
    "Atomic Weight": 264,
    "Period": 7,
    "Group": 7,
    "Phase": "artificial",
    "Most Stable Crystal": "",
    "Type": "Transactinide",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": "",
    "Density": 37,
    "Melting Point (K)": "",
    "Boiling Point (K)": "",
    "Isotopes": "",
    "Discoverer": "Armbruster and M�nzenberg",
    "Year of Discovery": 1981,
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 7,
    "Display Column": 7
  },
  {
    "Atomic Number": 108,
    "Element": "Hassium",
    "Symbol": "Hs",
    "Atomic Radius": "",
    "Atomic Weight": 267,
    "Period": 7,
    "Group": 8,
    "Phase": "artificial",
    "Most Stable Crystal": "",
    "Type": "Transactinide",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": "",
    "Density": 41,
    "Melting Point (K)": "",
    "Boiling Point (K)": "",
    "Isotopes": "",
    "Discoverer": "Armbruster and M�nzenberg",
    "Year of Discovery": 1983,
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 7,
    "Display Column": 8
  },
  {
    "Atomic Number": 109,
    "Element": "Meitnerium",
    "Symbol": "Mt",
    "Atomic Radius": "",
    "Atomic Weight": 268,
    "Period": 7,
    "Group": 9,
    "Phase": "artificial",
    "Most Stable Crystal": "",
    "Type": "Transactinide",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": "",
    "Density": 35,
    "Melting Point (K)": "",
    "Boiling Point (K)": "",
    "Isotopes": "",
    "Discoverer": "GSI, Darmstadt, West Germany",
    "Year of Discovery": 1982,
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 7,
    "Display Column": 9
  },
  {
    "Atomic Number": 110,
    "Element": "Darmstadtium",
    "Symbol": "Ds",
    "Atomic Radius": "",
    "Atomic Weight": 271,
    "Period": 7,
    "Group": 10,
    "Phase": "artificial",
    "Most Stable Crystal": "",
    "Type": "Transactinide",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": "",
    "Density": "",
    "Melting Point (K)": "",
    "Boiling Point (K)": "",
    "Isotopes": "",
    "Discoverer": "",
    "Year of Discovery": "",
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 7,
    "Display Column": 10
  },
  {
    "Atomic Number": 111,
    "Element": "Roentgenium",
    "Symbol": "Rg",
    "Atomic Radius": "",
    "Atomic Weight": 272,
    "Period": 7,
    "Group": 11,
    "Phase": "artificial",
    "Most Stable Crystal": "",
    "Type": "Transactinide",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": "",
    "Density": "",
    "Melting Point (K)": "",
    "Boiling Point (K)": "",
    "Isotopes": "",
    "Discoverer": "",
    "Year of Discovery": "",
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 7,
    "Display Column": 11
  },
  {
    "Atomic Number": 112,
    "Element": "Copernicium",
    "Symbol": "Cn",
    "Atomic Radius": "",
    "Atomic Weight": 285,
    "Period": 7,
    "Group": 12,
    "Phase": "artificial",
    "Most Stable Crystal": "",
    "Type": "Transactinide",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": "",
    "Density": "",
    "Melting Point (K)": "",
    "Boiling Point (K)": "",
    "Isotopes": "",
    "Discoverer": "",
    "Year of Discovery": "",
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 7,
    "Display Column": 12
  },
  {
    "Atomic Number": 113,
    "Element": "Ununtrium",
    "Symbol": "Uut",
    "Atomic Radius": "",
    "Atomic Weight": 284,
    "Period": 7,
    "Group": 13,
    "Phase": "artificial",
    "Most Stable Crystal": "",
    "Type": "",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": "",
    "Density": "",
    "Melting Point (K)": "",
    "Boiling Point (K)": "",
    "Isotopes": "",
    "Discoverer": "",
    "Year of Discovery": "",
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 7,
    "Display Column": 13
  },
  {
    "Atomic Number": 114,
    "Element": "Ununquadium",
    "Symbol": "Uuq",
    "Atomic Radius": "",
    "Atomic Weight": 289,
    "Period": 7,
    "Group": 14,
    "Phase": "artificial",
    "Most Stable Crystal": "",
    "Type": "Transactinide",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": "",
    "Density": "",
    "Melting Point (K)": "",
    "Boiling Point (K)": "",
    "Isotopes": "",
    "Discoverer": "",
    "Year of Discovery": "",
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 7,
    "Display Column": 14
  },
  {
    "Atomic Number": 115,
    "Element": "Ununpentium",
    "Symbol": "Uup",
    "Atomic Radius": "",
    "Atomic Weight": 288,
    "Period": 7,
    "Group": 15,
    "Phase": "artificial",
    "Most Stable Crystal": "",
    "Type": "",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": "",
    "Density": "",
    "Melting Point (K)": "",
    "Boiling Point (K)": "",
    "Isotopes": "",
    "Discoverer": "",
    "Year of Discovery": "",
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 7,
    "Display Column": 15
  },
  {
    "Atomic Number": 116,
    "Element": "Ununhexium",
    "Symbol": "Uuh",
    "Atomic Radius": "",
    "Atomic Weight": 292,
    "Period": 7,
    "Group": 16,
    "Phase": "artificial",
    "Most Stable Crystal": "",
    "Type": "Transactinide",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": "",
    "Density": "",
    "Melting Point (K)": "",
    "Boiling Point (K)": "",
    "Isotopes": "",
    "Discoverer": "",
    "Year of Discovery": "",
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 7,
    "Display Column": 16
  },
  {
    "Atomic Number": 117,
    "Element": "Ununseptium",
    "Symbol": "Uus",
    "Atomic Radius": "",
    "Atomic Weight": 295,
    "Period": 7,
    "Group": 17,
    "Phase": "artificial",
    "Most Stable Crystal": "",
    "Type": "",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": "",
    "Density": "",
    "Melting Point (K)": "",
    "Boiling Point (K)": "",
    "Isotopes": "",
    "Discoverer": "",
    "Year of Discovery": "",
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 7,
    "Display Column": 17
  },
  {
    "Atomic Number": 118,
    "Element": "Ununoctium",
    "Symbol": "Uuo",
    "Atomic Radius": "",
    "Atomic Weight": 294,
    "Period": 7,
    "Group": 18,
    "Phase": "artificial",
    "Most Stable Crystal": "",
    "Type": "Noble Gas",
    "Ionic Radius": "",
    "Electronegativity": "",
    "First Ionization Potential": "",
    "Density": "",
    "Melting Point (K)": "",
    "Boiling Point (K)": "",
    "Isotopes": "",
    "Discoverer": "",
    "Year of Discovery": "",
    "Specific Heat Capacity": "",
    "Electron Configuration": "",
    "Display Row": 7,
    "Display Column": 18
  }
]